@@ -146,7 +146,12 @@
      DATABASE_OPEN = 363,
      ALIGNOF = 364,
      ATTRIB_DEP = 365,
-     __ATTRIB = 366
+     __ATTRIB = 366,
+     BOOL = 367,
+     _BOOL = 368,
+     _COMPLEX = 369,
+     _IMAGINARY = 370,
+     RESTRICT = 371
    };
 #endif
 
@@ -157,7 +162,7 @@ typedef union YYSTYPE
 {
 
 /* Line 1685 of yacc.c  */
-#line 35 "grammar.y"
+#line 37 "grammar.y"
 
    SpecifierType specifierType;
    int i;
@@ -195,7 +200,7 @@ typedef union YYSTYPE
    TemplateParameter templateParameter;
    TemplateArgument templateArgument;
    TemplateDatatype templateDatatype;
-   
+
    DBTableEntry dbtableEntry;
    DBIndexItem dbindexItem;
    DBTableDef dbtableDef;
@@ -203,7 +208,7 @@ typedef union YYSTYPE
 
 
 /* Line 1685 of yacc.c  */
-#line 207 "grammar.h"
+#line 212 "grammar.h"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
