@@ -48,6 +48,7 @@ void * __ecereNameSpace__ecere__com__eSystem_Renew0(void * memory, unsigned int
 unsigned short * __ecereNameSpace__ecere__sys__UTF8toUTF16(char * source, int * wordCount);
 unsigned short * __ecereNameSpace__ecere__sys__UTF8toUTF16Buffer(char * source, uint16 * dest, int max);
 char * __ecereNameSpace__ecere__sys__UTF16toUTF8(uint16 * source);
+void __ecereNameSpace__ecere__sys__ChangeCh(char * string, char ch1, char ch2);
 
 #if defined(__WIN32__) || defined(__WATCOMC__)
 #include <direct.h>
@@ -110,11 +111,11 @@ static BOOL CALLBACK EnumThreadWindowsProc(HWND hwnd, LPARAM lParam)
 {
    DWORD pid;
    if(IsWindowVisible(hwnd) && GetWindowThreadProcessId(hwnd, &pid) && pid == GetCurrentProcessId())
-   {      
+   {
       *(void **)lParam = hwnd;
       return FALSE;
    }
-   return TRUE;   
+   return TRUE;
 }
 bool WinReviveNetworkResource(uint16 * _wfileName)
 {
@@ -146,7 +147,7 @@ bool WinReviveNetworkResource(uint16 * _wfileName)
    if(!windowHandle)
    {
       EnumWindows(EnumThreadWindowsProc, (LPARAM)&windowHandle);
-      
+
    }
    if(WNetAddConnection3(windowHandle, &nr, null, null, CONNECT_INTERACTIVE|CONNECT_PROMPT) == NO_ERROR)
       result = true;
@@ -188,7 +189,7 @@ bool FILE_Lock(FILE * input, FILE * output, FileLock type, uint64 start, uint64
             (uint)(length ? ((length & 0xFFFFFFFF00000000LL) >> 32) : 0xFFFFFFFF),
             &overlapped) != 0;
       else
-         return LockFileEx(hFile, ((type == exclusive) ? LOCKFILE_EXCLUSIVE_LOCK : 0) | (wait ? 0 : LOCKFILE_FAIL_IMMEDIATELY), 0, 
+         return LockFileEx(hFile, ((type == exclusive) ? LOCKFILE_EXCLUSIVE_LOCK : 0) | (wait ? 0 : LOCKFILE_FAIL_IMMEDIATELY), 0,
             (uint)(length ? (length & 0xFFFFFFFF) : 0xFFFFFFFF),
             (uint)(length ? ((length & 0xFFFFFFFF00000000LL) >> 32) : 0xFFFFFFFF),
             &overlapped) != 0;
@@ -204,7 +205,7 @@ bool FILE_Lock(FILE * input, FILE * output, FileLock type, uint64 start, uint64
 
       fd = fileno(output ? output : input);
       return fcntl(fd, wait ? F_SETLKW : F_SETLK, &fl) != -1;
-#endif      
+#endif
    }
 }
 
@@ -347,7 +348,7 @@ bool FILE_FileGetStats(char * fileName, FileStats * stats)
             stats->accessed = Win32FileTimeToTimeStamp(&a);
             stats->modified = Win32FileTimeToTimeStamp(&m);
 #endif
-            
+
             CloseHandle(hFile);
          }
       }
@@ -382,7 +383,8 @@ void FILE_FileFixCase(char * file)
       char fileName[MAX_LOCATION];
       strcpy(fileName, name);
       __ecereMethod___ecereNameSpace__ecere__sys__EARFileSystem_FixCase(archive, fileName);
-      FILE_FileFixCase(archive);
+      if(archive[0] != ':')
+         FILE_FileFixCase(archive);
       sprintf(file, "<%s>%s", archive, fileName);
    }
    else
@@ -409,9 +411,15 @@ void FILE_FileFixCase(char * file)
          parent[2] = '\0';
          c = 2;
       }
+      else if(file[0] == '/' && file[1] == '/')
+      {
+         parent[0] = parent[1] = '\\';
+         parent[2] = '\0';
+         c = 2;
+      }
       // Copy Entire Computer to new path
       else if(file[0] == '/'  && !file[1])
-   
+
       {
          parent[0] = '/';
          parent[1] = '\0';
@@ -428,7 +436,7 @@ void FILE_FileFixCase(char * file)
          for(;(ch = file[c]) && (ch != '/' && ch != '\\'); c++)
          {
             if(len < MAX_FILENAME)
-               directory[len++] = ch;  
+               directory[len++] = ch;
          }
          directory[len] = '\0';
 
@@ -539,6 +547,8 @@ void FILE_FileFixCase(char * file)
       }
       strcpy(file, parent);
    }
+#else
+   __ecereNameSpace__ecere__sys__ChangeCh(file, '\\', '/');
 #endif
 }
 
